using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.Xna.Framework;
using Microsoft.Xna.Framework.Audio;
using Microsoft.Xna.Framework.Content;
using Microsoft.Xna.Framework.GamerServices;
using Microsoft.Xna.Framework.Graphics;
using Microsoft.Xna.Framework.Input;
using Microsoft.Xna.Framework.Media;
using XNACS1Lib;

/// Information on Resoruces:
/// 
/// Images: All images download from: Microsoft Office Clipart: http://office.microsoft.com/en-us/images/
///         format of images may have been converted.
/// 
/// Audio Effect: Recrord by Kelvin Sung.
/// 
/// Background audio: BackgroundMusic.mp3
///     Extracted from: Somewhere Sunny (ver 2).mp3
///     Downloaded from: incompetech.com
///     Original Composer: Kevin MacLeod
///     


namespace ClassExample
{
    /// <summary>
    /// This is the main type for your game
    /// </summary>
    public class ClassExample : XNACS1Base
    {
        #region Declare a circle and the paddles
        XNACS1Circle myCircle;
        XNACS1Rectangle leftPaddle;
        XNACS1Rectangle rightPaddle;
        #endregion 

        // variable for horizontal speed
        float speedX;


        /// <summary>
        /// Initialize the internal state of your game
        /// </summary>
        protected override void InitializeWorld()
        {
            // Default window size is 800x600
            #region Initialize the window and coordinate
            const float kBgAudioLevel = 0.1f;   // Default Audio level
            const int kWindowWidth = 800;       // Default Window Width
            const int kWindowHeight = 600;      // Default Window Height

            PlayBackgroundAudio("BackgroundMusic", kBgAudioLevel);          // Background audio
            SetAppWindowPixelDimension(false, kWindowWidth, kWindowHeight); // Not full screen
            World.SetWorldCoordinate(Vector2.Zero, kWindowWidth);           // Each pixel is one unit
            #endregion

            #region the soccer and the paddles
            // Define the circle
            myCircle = new XNACS1Circle();
                // now sets the initial values for the circle
            myCircle.CenterX = 400f;    // Center's X position
            myCircle.CenterY = 300f;    // Center's Y position
            myCircle.Radius = 25f;      // Radius of the circle
            myCircle.Texture = "SoccerBall"; // What texture (image) to use

            // define the paddles
            leftPaddle = new XNACS1Rectangle();
            leftPaddle.CenterX = 30f;
            leftPaddle.CenterY = 300f;
            leftPaddle.Width = 15f;
            leftPaddle.Height = 100f;
            leftPaddle.Color = Color.Brown;
            leftPaddle.Label = "Left\nPaddle";

            rightPaddle = new XNACS1Rectangle();
            rightPaddle.CenterX = 770f;
            rightPaddle.CenterY = 300f;
            rightPaddle.Width = 15f;
            rightPaddle.Height = 100f;
            rightPaddle.Color = Color.Pink;
            rightPaddle.Label = "Right\nPaddle";
            #endregion

            // initialize the value of speedX
            speedX = 0.5f;
        }

        /// <summary>
        /// Update the internal state of your game
        /// </summary>
        protected override void UpdateWorld()
        {
            #region Quit: if the back-button ("F1") is pressed
            if (GamePad.ButtonBackClicked())
                Exit();
            #endregion 
            
            // Change the circle's centerX by speedX: 60 times a second
            myCircle.CenterX += speedX;

            EchoToTopStatus("Current Ball at" + myCircle.Center);
            EchoToBottomStatus("Does this look like Pong? What do we need to get this working?");
        }
    }
}